from setuptools import setup

setup(
    name='nola',
    version='1.63',
    packages=['stations'],
    url='',
    license='',
    author='kerstinFrailey',
    author_email='frailey.work@gmail.com',
    description=''
)
